Code coverage report for js/widgets/UrlInputWidget.tsx

# All files / js/widgets UrlInputWidget.tsx

50% Statements 4/8
0% Branches 0/4
0% Functions 0/2
50% Lines 4/8

Press n or j to go to the next uncovered block, b, p or k for the previous block.

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    14
    15
    16
    17
    18
    19
    20
    21
    22
    23
    241x

    1x
    1x
    1x

     import React from "react";
    import { WidgetProps } from "./types";
    import InputWidgetBase from "./InputWidgetBase";
    import { isValidUrl } from "../utils";
    import { trans } from "../i18n";

    function validateUrl(value: string) {
      if (value && !isValidUrl(value)) {
        return trans("ERROR_INVALID_URL");
      }
      return null;
    }

    export function UrlInputWidget(props: WidgetProps) {
      return (
        <InputWidgetBase
          inputType="text"
          inputAddon={<i className="fa fa-external-link" />}
          validate={validateUrl}
          {...props}
        />
      );
    }